package com.order.controller;

import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hfkj.common.exception.ErrorCode;
import com.hfkj.common.exception.ErrorHelp;
import com.hfkj.common.exception.SysCode;
import com.hfkj.common.security.UserCenter;
import com.hfkj.common.utils.ResponseMsgUtil;
import com.hfkj.entity.BsOrderRefund;
import com.hfkj.model.ResponseData;
import com.hfkj.model.UserSessionObject;
import com.hfkj.model.order.OrderChildModel;
import com.hfkj.model.order.OrderModel;
import com.hfkj.service.order.BsOrderRefundService;
import com.hfkj.service.order.BsOrderService;
import com.hfkj.sysenum.UserStatusEnum;
import com.hfkj.sysenum.order.OrderChildProductTypeEnum;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;

/**
 * @className: OrderController
 * @author: HuRui
 * @date: 2024/4/30
 **/
@Controller
@RequestMapping(value="/refund")
@Api(value="订单退款业务")
public class OrderRefundController {

    Logger log = LoggerFactory.getLogger(OrderRefundController.class);
    @Resource
    private UserCenter userCenter;
    @Resource
    private BsOrderRefundService orderRefundService;

    @RequestMapping(value="/tradeOrder",method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "退款交易订单")
    public ResponseData tradeOrder(@RequestBody JSONObject body) {
        try {
            // 用户session
            UserSessionObject userSession = userCenter.getSessionModel(UserSessionObject.class);
            if (userSession == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ACCOUNT_LOGIN_NOT, "");
            }
            if (body == null || StringUtils.isBlank(body.getString("orderNo"))) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }

            return ResponseMsgUtil.success(orderRefundService.tradeOrderRefund(body.getString("orderNo"),body.getString("remark")));

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value="/tradeOrderChild",method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "退款交易子订单")
    public ResponseData tradeOrderChild(@RequestBody JSONObject body) {
        try {
            // 用户session
            UserSessionObject userSession = userCenter.getSessionModel(UserSessionObject.class);
            if (userSession == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ACCOUNT_LOGIN_NOT, "");
            }
            if (!userSession.getUser().getStatus().equals(UserStatusEnum.status1.getCode())) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "该账户已被禁用，无法进行交易");
            }
            if (body == null
                    || StringUtils.isBlank(body.getString("childOrderNo"))
                    || body.getInteger("productCount") == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }

            return ResponseMsgUtil.success(orderRefundService.tradeOrderChildRefund(
                    body.getString("childOrderNo"),
                    body.getInteger("productCount"),
                    body.getString("remark")
            ));

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value="/queryOrderRefund",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询退款订单")
    public ResponseData queryOrderRefund(@RequestParam(value = "orderNo" , required = false) String orderNo,
                                         @RequestParam(value = "orderChildNo" , required = false) String orderChildNo,
                                         @RequestParam(value = "refundOrderNo" , required = false) String refundOrderNo) {
        try {
            if (StringUtils.isBlank(orderNo)
                    && StringUtils.isBlank(orderChildNo)
                    && StringUtils.isBlank(refundOrderNo)) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }

            Map<String,Object> param = new HashMap<>();
            param.put("orderNo", orderNo);
            param.put("orderChildNo", orderChildNo);
            param.put("refundOrderNo", refundOrderNo);
            return ResponseMsgUtil.success(orderRefundService.getRefundList(param));

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }


}
